pub fn initial_bearing_deg(from: Position, to: Position) -> f64Expand description
The bearing to leave from on to reach to by the great circle, in
degrees true.
Only the initial bearing: on any leg that is not along a meridian or
the equator, holding this bearing does not arrive at to. See
final_bearing_deg for the other end, and crate::rhumb for the
constant-bearing alternative.